ulaval\_notify package
======================

Submodules
----------

ulaval\_notify\.constants module
--------------------------------

.. automodule:: ulaval_notify.constants
    :members:
    :undoc-members:
    :show-inheritance:

ulaval\_notify\.main module
---------------------------

.. automodule:: ulaval_notify.main
    :members:
    :undoc-members:
    :show-inheritance:

ulaval\_notify\.options module
------------------------------

.. automodule:: ulaval_notify.options
    :members:
    :undoc-members:
    :show-inheritance:

ulaval\_notify\.utils module
----------------------------

.. automodule:: ulaval_notify.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ulaval_notify
    :members:
    :undoc-members:
    :show-inheritance:
